pub fn load_from_path(path: &Path) -> Result<Pipe, ParseError>Expand description
Read a pipe file, extract frontmatter, and parse into a Pipe.
pub fn load_from_path(path: &Path) -> Result<Pipe, ParseError>Read a pipe file, extract frontmatter, and parse into a Pipe.